# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import datetime
from datetime import timezone
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('diary', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='entry',
            name='edited',
            field=models.DateTimeField(
                auto_now=True, 
                default=datetime.datetime(
                    2015, 10, 10, 12, 24, 48, 619511, 
                    tzinfo=timezone.utc
                )
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='entry',
            name='editor',
            field=models.ForeignKey(
                null=True, 
                blank=True, 
                to=settings.AUTH_USER_MODEL, 
                related_name='edited_entries', 
                on_delete=models.CASCADE
            ),
        ),
    ]



# Generated by Django 4.2.4 on 2023-09-15 12:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('diary', '0007_auto_20151017_1348'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='opt_out_entry_change_email',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='customer',
            name='opt_out_entry_reminder_email',
            field=models.BooleanField(default=False),
        ),
    ]



# Generated by Django 4.2.5 on 2023-09-22 13:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('diary', '0009_resource_bg_color_resource_fg_color'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='enabled',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='resource',
            name='bg_color',
            field=models.CharField(choices=[('Black', 'Black'), ('White', 'White'), ('Silver', 'Silver'), ('LightGrey', 'Light Grey'), ('DarkGrey', 'Dark Grey'), ('Red', 'Red'), ('Crimson', 'Crimson'), ('DarkRed', 'Dark Red'), ('Magenta', 'Magenta'), ('DarkMagenta', 'Dark Magenta'), ('Green', 'Green'), ('LightGreen', 'Light Green'), ('DarkGreen', 'Dark Green'), ('YellowGreen', 'Yellow Green'), ('Blue', 'Blue'), ('LightBlue', 'Light Blue'), ('DarkBlue', 'Dark Blue'), ('RoyalBlue', 'Royal Blue'), ('Teal', 'Teal'), ('Yellow', 'Yellow'), ('LightYellow', 'Light Yellow'), ('Gold', 'Gold'), ('GoldenRod', 'Golden Rod'), ('LightGoldenRodYellow', 'Light Golden Rod Yellow'), ('DarkGoldenRod', 'Dark Golden Rod'), ('Brown', 'Brown'), ('Tan', 'Tan'), ('SandyBrown', 'Sandy Brown'), ('Pink', 'Pink'), ('LightPink', 'Light Pink'), ('Salmon', 'Salmon'), ('LightSalmon', 'Light Salmon'), ('Purple', 'Purple'), ('Violet', 'Violet'), ('PaleVioletRed', 'Pale Violet Red'), ('DarkViolet', 'Dark Violet')], default='White', max_length=20),
        ),
        migrations.AlterField(
            model_name='resource',
            name='fg_color',
            field=models.CharField(choices=[('Black', 'Black'), ('White', 'White'), ('Silver', 'Silver'), ('LightGrey', 'Light Grey'), ('DarkGrey', 'Dark Grey'), ('Red', 'Red'), ('Crimson', 'Crimson'), ('DarkRed', 'Dark Red'), ('Magenta', 'Magenta'), ('DarkMagenta', 'Dark Magenta'), ('Green', 'Green'), ('LightGreen', 'Light Green'), ('DarkGreen', 'Dark Green'), ('YellowGreen', 'Yellow Green'), ('Blue', 'Blue'), ('LightBlue', 'Light Blue'), ('DarkBlue', 'Dark Blue'), ('RoyalBlue', 'Royal Blue'), ('Teal', 'Teal'), ('Yellow', 'Yellow'), ('LightYellow', 'Light Yellow'), ('Gold', 'Gold'), ('GoldenRod', 'Golden Rod'), ('LightGoldenRodYellow', 'Light Golden Rod Yellow'), ('DarkGoldenRod', 'Dark Golden Rod'), ('Brown', 'Brown'), ('Tan', 'Tan'), ('SandyBrown', 'Sandy Brown'), ('Pink', 'Pink'), ('LightPink', 'Light Pink'), ('Salmon', 'Salmon'), ('LightSalmon', 'Light Salmon'), ('Purple', 'Purple'), ('Violet', 'Violet'), ('PaleVioletRed', 'Pale Violet Red'), ('DarkViolet', 'Dark Violet')], default='Black', max_length=20),
        ),
    ]



"""
Custom tags for use with the diary app.
"""
from django import template

register = template.Library()

@register.simple_tag
def update_variable(value):
    """
    Allows to update existing variable in template
    https://stackoverflow.com/questions/31916408/is-django-can-modify-variable-value-in-template
    """
    return value



# Generated by Django 4.2.5 on 2023-09-21 13:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('diary', '0008_customer_opt_out_entry_change_email_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='bg_color',
            field=models.CharField(choices=[('Black', 'Black'), ('White', 'White'), ('Red', 'Red'), ('Green', 'Green'), ('Blue', 'Blue'), ('Yellow', 'Yellow'), ('Pink', 'Pink')], default='White', max_length=20),
        ),
        migrations.AddField(
            model_name='resource',
            name='fg_color',
            field=models.CharField(choices=[('Black', 'Black'), ('White', 'White'), ('Red', 'Red'), ('Green', 'Green'), ('Blue', 'Blue'), ('Yellow', 'Yellow'), ('Pink', 'Pink')], default='Black', max_length=20),
        ),
    ]
